
class Qbitskipselection(Exception):
    pass

class Aria2pcancel(Exception):
    pass

class Aria2perrors(Exception):
    pass

class Qbitorerrors(Exception):
    pass

class Qbitorcancel(Exception):
    pass
